==> kubernetes-model-policy-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/policy/FSGroupStrategyOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FSGroupStrategyOptionsFluent<A extends FSGroupStrategyOptionsFluent<A>> extends Fluent<A> {


    public A addToRanges(int index,IDRange item);
    public A setToRanges(int index,IDRange item);
    public A addToRanges(IDRange... items);
    public A addAllToRanges(Collection<IDRange> items);
    public A removeFromRanges(IDRange... items);
    public A removeAllFromRanges(Collection<IDRange> items);
    public A removeMatchingFromRanges(Predicate<IDRangeBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<IDRange> getRanges();
    public List<IDRange> buildRanges();
    public IDRange buildRange(int index);
    public IDRange buildFirstRange();
    public IDRange buildLastRange();
    public IDRange buildMatchingRange(Predicate<IDRangeBuilder> predicate);
    public Boolean hasMatchingRange(Predicate<IDRangeBuilder> predicate);
    public A withRanges(List<IDRange> ranges);
    public A withRanges(IDRange... ranges);
    public Boolean hasRanges();
    public A addNewRange(Long max,Long min);
    public FSGroupStrategyOptionsFluent.RangesNested<A> addNewRange();
    public FSGroupStrategyOptionsFluent.RangesNested<A> addNewRangeLike(IDRange item);
    public FSGroupStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,IDRange item);
    public FSGroupStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public FSGroupStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public FSGroupStrategyOptionsFluent.RangesNested<A> editLastRange();
    public FSGroupStrategyOptionsFluent.RangesNested<A> editMatchingRange(Predicate<IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    public A withNewRule(StringBuilder arg1);
    public A withNewRule(int[] arg1,int arg2,int arg3);
    public A withNewRule(char[] arg1);
    public A withNewRule(StringBuffer arg1);
    public A withNewRule(byte[] arg1,int arg2);
    public A withNewRule(byte[] arg1);
    public A withNewRule(char[] arg1,int arg2,int arg3);
    public A withNewRule(byte[] arg1,int arg2,int arg3);
    public A withNewRule(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRule(String arg1);
    public interface RangesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IDRangeFluent<FSGroupStrategyOptionsFluent.RangesNested<N>> {

            public N and();
            public N endRange();    }


}

==> kubernetes-model-policy-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/policy/FSGroupStrategyOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FSGroupStrategyOptionsFluent<A extends FSGroupStrategyOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToRanges(int index,IDRange item);
    public A setToRanges(int index,IDRange item);
    public A addToRanges(IDRange... items);
    public A addAllToRanges(Collection<IDRange> items);
    public A removeFromRanges(IDRange... items);
    public A removeAllFromRanges(Collection<IDRange> items);
    public A removeMatchingFromRanges(Predicate<IDRangeBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<IDRange> getRanges();
    public List<IDRange> buildRanges();
    public IDRange buildRange(int index);
    public IDRange buildFirstRange();
    public IDRange buildLastRange();
    public IDRange buildMatchingRange(Predicate<IDRangeBuilder> predicate);
    public Boolean hasMatchingRange(Predicate<IDRangeBuilder> predicate);
    public A withRanges(List<IDRange> ranges);
    public A withRanges(IDRange... ranges);
    public Boolean hasRanges();
    public A addNewRange(Long max,Long min);
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> addNewRange();
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> addNewRangeLike(IDRange item);
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,IDRange item);
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> editLastRange();
    public io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<A> editMatchingRange(Predicate<IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    public A withNewRule(StringBuilder arg1);
    public A withNewRule(int[] arg1,int arg2,int arg3);
    public A withNewRule(char[] arg1);
    public A withNewRule(StringBuffer arg1);
    public A withNewRule(byte[] arg1,int arg2);
    public A withNewRule(byte[] arg1);
    public A withNewRule(char[] arg1,int arg2,int arg3);
    public A withNewRule(byte[] arg1,int arg2,int arg3);
    public A withNewRule(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRule(String arg1);
    public interface RangesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IDRangeFluent<io.fabric8.kubernetes.api.model.policy.FSGroupStrategyOptionsFluent.RangesNested<N>> {

            public N and();
            public N endRange();    }


}
